@@ -66,19 +66,15 @@ class DQN(nn.Module):
             n_actions: number of discrete actions available in the environment
             hidden_size: size of hidden layers
         """
-        super(DQN, self).__init__()
-        self.net = nn.Sequential(
-            nn.Linear(obs_size, hidden_size),
-            nn.ReLU(),
-            nn.Linear(hidden_size, n_actions),
-        )
+        super().__init__()
+        self.net = nn.Sequential(nn.Linear(obs_size, hidden_size), nn.ReLU(), nn.Linear(hidden_size, n_actions))
 
     def forward(self, x):
         return self.net(x.float())
 
 
 # Named tuple for storing experience steps gathered in training
-Experience = namedtuple('Experience', field_names=['state', 'action', 'reward', 'done', 'new_state'])
+Experience = namedtuple("Experience", field_names=["state", "action", "reward", "done", "new_state"])
 
 
 class ReplayBuffer:
@@ -110,7 +106,7 @@ class ReplayBuffer:
 
     def sample(self, batch_size: int) -> Tuple:
         indices = np.random.choice(len(self.buffer), batch_size, replace=False)
-        states, actions, rewards, dones, next_states = zip(*[self.buffer[idx] for idx in indices])
+        states, actions, rewards, dones, next_states = zip(*(self.buffer[idx] for idx in indices))
 
         return (
             np.array(states),
@@ -188,7 +184,7 @@ class Agent:
         else:
             state = torch.tensor([self.state])
 
-            if device not in ['cpu']:
+            if device not in ["cpu"]:
                 state = state.cuda(device)
 
             q_values = net(state)
@@ -198,7 +194,7 @@ class Agent:
         return action
 
     @torch.no_grad()
-    def play_step(self, net: nn.Module, epsilon: float = 0.0, device: str = 'cpu') -> Tuple[float, bool]:
+    def play_step(self, net: nn.Module, epsilon: float = 0.0, device: str = "cpu") -> Tuple[float, bool]:
         """
         Carries out a single interaction step between the agent and the environment
 
@@ -227,7 +223,7 @@ class Agent:
 
 
 class DQNLightning(pl.LightningModule):
-    """ Basic DQN Model
+    """Basic DQN Model
 
     >>> DQNLightning(env="CartPole-v1")  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
     DQNLightning(
@@ -358,12 +354,12 @@ class DQNLightning(pl.LightningModule):
             self.target_net.load_state_dict(self.net.state_dict())
 
         log = {
-            'total_reward': torch.tensor(self.total_reward).to(device),
-            'reward': torch.tensor(reward).to(device),
-            'steps': torch.tensor(self.global_step).to(device)
+            "total_reward": torch.tensor(self.total_reward).to(device),
+            "reward": torch.tensor(reward).to(device),
+            "steps": torch.tensor(self.global_step).to(device),
         }
 
-        return OrderedDict({'loss': loss, 'log': log, 'progress_bar': log})
+        return OrderedDict({"loss": loss, "log": log, "progress_bar": log})
 
     def configure_optimizers(self) -> List[Optimizer]:
         """Initialize Adam optimizer"""
@@ -373,11 +369,7 @@ class DQNLightning(pl.LightningModule):
     def __dataloader(self) -> DataLoader:
         """Initialize the Replay Buffer dataset used for retrieving experiences"""
         dataset = RLDataset(self.buffer, self.episode_length)
-        dataloader = DataLoader(
-            dataset=dataset,
-            batch_size=self.batch_size,
-            sampler=None,
-        )
+        dataloader = DataLoader(dataset=dataset, batch_size=self.batch_size, sampler=None)
         return dataloader
 
     def train_dataloader(self) -> DataLoader:
@@ -386,7 +378,7 @@ class DQNLightning(pl.LightningModule):
 
     def get_device(self, batch) -> str:
         """Retrieve device currently being used by minibatch"""
-        return batch[0].device.index if self.on_gpu else 'cpu'
+        return batch[0].device.index if self.on_gpu else "cpu"
 
     @staticmethod
     def add_model_specific_args(parent_parser):  # pragma: no-cover
@@ -401,7 +393,7 @@ class DQNLightning(pl.LightningModule):
             "--warm_start_steps",
             type=int,
             default=1000,
-            help="how many samples do we use to fill our buffer at the start of training"
+            help="how many samples do we use to fill our buffer at the start of training",
         )
         parser.add_argument("--eps_last_frame", type=int, default=1000, help="what frame should epsilon stop decaying")
         parser.add_argument("--eps_start", type=float, default=1.0, help="starting value of epsilon")
@@ -413,16 +405,12 @@ class DQNLightning(pl.LightningModule):
 def main(args) -> None:
     model = DQNLightning(**vars(args))
 
-    trainer = pl.Trainer(
-        gpus=1,
-        accelerator='dp',
-        val_check_interval=100,
-    )
+    trainer = pl.Trainer(gpus=1, accelerator="dp", val_check_interval=100)
 
     trainer.fit(model)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli_lightning_logo()
     torch.manual_seed(0)
     np.random.seed(0)
