@@ -16,7 +16,7 @@ from typing import Optional, Tuple, Union
 import torch
 from torchmetrics.functional import psnr as _psnr
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
 @deprecated_metrics(target=_psnr)
@@ -25,10 +25,11 @@ def psnr(
     target: torch.Tensor,
     data_range: Optional[float] = None,
     base: float = 10.0,
-    reduction: str = 'elementwise_mean',
+    reduction: str = "elementwise_mean",
     dim: Optional[Union[int, Tuple[int, ...]]] = None,
 ) -> torch.Tensor:
     """
     .. deprecated::
         Use :func:`torchmetrics.functional.psnr`. Will be removed in v1.5.0.
     """
+    return void(preds, target, data_range, base, reduction, dim)
