@@ -15,17 +15,15 @@
 import torch
 from torchmetrics.functional import r2score as _r2score
 
-from pytorch_lightning.metrics.utils import deprecated_metrics
+from pytorch_lightning.metrics.utils import deprecated_metrics, void
 
 
 @deprecated_metrics(target=_r2score)
 def r2score(
-    preds: torch.Tensor,
-    target: torch.Tensor,
-    adjusted: int = 0,
-    multioutput: str = "uniform_average",
+    preds: torch.Tensor, target: torch.Tensor, adjusted: int = 0, multioutput: str = "uniform_average"
 ) -> torch.Tensor:
     """
     .. deprecated::
         Use :func:`torchmetrics.functional.r2score`. Will be removed in v1.5.0.
     """
+    return void(preds, target, adjusted, multioutput)
